import json
from argparse import ArgumentParser, Namespace
from json import JSONDecodeError
from pathlib import Path
from typing import Optional, Sequence


def main(argv: Optional[Sequence[str]] = None) -> int:
    args = parse_arguments(argv)

    return_value = 0
    for filename in args.filenames:
        json_file = Path(filename).resolve()
        with json_file.open("r") as stream:
            try:
                content = json.load(stream)
            except JSONDecodeError as err:
                print(f"Unable to decode {filename}: {err}")
                return_value = 1
                continue
        with json_file.open("w") as stream:
            json.dump(
                content,
                stream,
                default=str,
                indent=args.indent,
                ensure_ascii=False,
                sort_keys=not args.no_sort,
            )
    return return_value


def parse_arguments(args: Optional[Sequence[str]] = None) -> Namespace:
    parser = ArgumentParser()
    parser.add_argument(
        "--indent",
        type=int,
        default=2,
        help="The number of spaces for indentation (Default: 2)",
    )
    parser.add_argument("--no-sort", action="store_true", help="Don't sort the result")
    parser.add_argument("filenames", nargs="*", help="Filenames to format.")
    return parser.parse_args(args)


if __name__ == "__main__":
    raise SystemExit(main())
