from argparse import ArgumentParser, Namespace
from pathlib import Path
from typing import Optional, Sequence

from toml_sort import TomlSort
from tomlkit.exceptions import ParseError


def main(argv: Optional[Sequence[str]] = None) -> int:
    args = parse_arguments(argv)

    return_value = 0
    for filename in args.filenames:
        toml_file = Path(filename).resolve()
        with toml_file.open("r") as stream:
            content = stream.read()
            try:
                content = TomlSort(content, ignore_case=True)
            except ParseError as err:
                print(f"Unable to decode {filename}: {err}")
                return_value = 1
                continue
        if not args.no_sort:
            content = content.sorted()
        with toml_file.open("w") as stream:
            stream.write(content)
    return return_value


def parse_arguments(args: Optional[Sequence[str]] = None) -> Namespace:
    parser = ArgumentParser()
    parser.add_argument(
        "--indent",
        type=int,
        default=2,
        help="The number of spaces for indentation (Default: 2)",
    )
    parser.add_argument("--no-sort", action="store_true", help="Don't sort the result")
    parser.add_argument("filenames", nargs="*", help="Filenames to format.")
    return parser.parse_args(args)


if __name__ == "__main__":
    raise SystemExit(main())
