from argparse import ArgumentParser, Namespace
from pathlib import Path
from typing import Optional, Sequence

import xmltodict


def main(argv: Optional[Sequence[str]] = None) -> int:
    args = parse_arguments(argv)

    return_value = 0
    for filename in args.filenames:
        xml_file = Path(filename).resolve()
        with xml_file.open("rb") as stream:
            content = xmltodict.parse(stream, dict_constructor=dict)
        with xml_file.open("wb") as stream:
            xmltodict.unparse(content, stream, short_empty_elements=True, pretty=True)
    return return_value


def parse_arguments(args: Optional[Sequence[str]] = None) -> Namespace:
    parser = ArgumentParser()
    parser.add_argument("filenames", nargs="*", help="Filenames to format.")
    return parser.parse_args(args)


if __name__ == "__main__":
    raise SystemExit(main())
