from copy import deepcopy

from ruamel.yaml import CommentedMap, CommentedSeq

from file_format.format_pre_commit import main, sort_data, sort_dict, sort_list

SORTED_MAP = CommentedMap(
    {
        "repos": CommentedSeq(
            [
                CommentedMap(
                    {
                        "repo": "https://github.com/asottile/pyupgrade",
                        "rev": "v2.31.0",
                        "hooks": CommentedSeq(
                            [
                                CommentedMap(
                                    {
                                        "id": "pyupgrade",
                                        "args": CommentedSeq(
                                            [
                                                "--py3-plus",
                                                "--py36-plus",
                                                "--py37-plus",
                                                "--py38-plus",
                                            ]
                                        ),
                                    }
                                )
                            ]
                        ),
                    }
                ),
                CommentedMap(
                    {
                        "repo": "https://github.com/Buried-In-Code/File-Format",
                        "rev": "0.1.5",
                        "hooks": CommentedSeq(
                            [
                                CommentedMap({"id": "format-json"}),
                                CommentedMap({"id": "format-pre-commit"}),
                                CommentedMap({"id": "format-toml"}),
                                CommentedMap({"id": "format-xml", "args": CommentedSeq([])}),
                                CommentedMap(
                                    {"id": "format-yaml", "exclude": r"^\.github.*|^\.pre-commit.*"}
                                ),
                                CommentedMap(
                                    {
                                        "id": "format-yaml",
                                        "name": "Format .github",
                                        "alias": "format-github",
                                        "args": CommentedSeq(["--no-sort", "--yaml-version=1.1"]),
                                        "files": r"^\.github.*",
                                    }
                                ),
                            ]
                        ),
                    }
                ),
            ]
        )
    }
)
UNSORTED_MAP = CommentedMap(
    {
        "repos": CommentedSeq(
            [
                CommentedMap(
                    {
                        "hooks": CommentedSeq(
                            [
                                CommentedMap(
                                    {
                                        "alias": "format-github",
                                        "args": CommentedSeq(["--no-sort", "--yaml-version=1.1"]),
                                        "files": r"^\.github.*",
                                        "id": "format-yaml",
                                        "name": "Format .github",
                                    }
                                ),
                                CommentedMap({"id": "format-json"}),
                                CommentedMap({"id": "format-pre-commit"}),
                                CommentedMap({"id": "format-toml"}),
                                CommentedMap({"id": "format-xml", "args": CommentedSeq([])}),
                                CommentedMap(
                                    {"exclude": r"^\.github.*|^\.pre-commit.*", "id": "format-yaml"}
                                ),
                            ]
                        ),
                        "repo": "https://github.com/Buried-In-Code/File-Format",
                        "rev": "0.1.5",
                    }
                ),
                CommentedMap(
                    {
                        "hooks": CommentedSeq(
                            [
                                CommentedMap(
                                    {
                                        "args": CommentedSeq(
                                            [
                                                "--py3-plus",
                                                "--py36-plus",
                                                "--py37-plus",
                                                "--py38-plus",
                                            ]
                                        ),
                                        "id": "pyupgrade",
                                    }
                                )
                            ]
                        ),
                        "repo": "https://github.com/asottile/pyupgrade",
                        "rev": "v2.31.0",
                    }
                ),
            ]
        )
    }
)


def test_sort_data():
    sorted_data = sort_data(deepcopy(UNSORTED_MAP))
    assert sorted_data == SORTED_MAP


def test_sort_dict():
    sorted_map = sort_dict(deepcopy(UNSORTED_MAP))
    assert sorted_map == SORTED_MAP


def test_sort_list():
    sorted_seq = sort_list(deepcopy(UNSORTED_MAP["repos"]))
    assert sorted_seq == SORTED_MAP["repos"]


def test_pre_commit():
    main(["test_files/test.pre-commit"])
